@@ -14,11 +14,9 @@
 #include <zypp/Locks.h>
 
 #include "output/Out.h"
-#include "main.h"
 #include "Table.h"
-#include "utils/misc.h"
-#include "repos.h"
-
+#include "Zypper.h"
+#include "main.h"
 
 #include "utils/flags/zyppflags.h"
 #include "utils/flags/flagtypes.h"
@@ -35,9 +33,9 @@ namespace out
     };
     if ( op_r != Rel::ANY && op_r != Rel::NONE )
       n.addAttr( {
-	{ "epoch",   ed_r.epoch() },
-	{ "version", ed_r.version() },
-	{ "release", ed_r.release() },
+        { "epoch",   ed_r.epoch() },
+        { "version", ed_r.version() },
+        { "release", ed_r.release() },
       } );
     return str;
   }
@@ -53,12 +51,12 @@ namespace out
 
       int doComapre( const sat::Solvable & lhs, const sat::Solvable & rhs ) const
       {
-	// do N(<) A(>) VR(>)
-	int res = sat::compareByN( lhs, rhs );									// ascending  l<r
-	if ( res == 0 ) res = rhs.arch().compare( lhs.arch() );							// descending r<l
-	if ( res == 0 ) res = rhs.edition().compare( lhs.edition() );						// descending r<l
-	if ( res == 0 ) res = lhs.repository().asUserString().compare( rhs.repository().asUserString() );	// ascending  l<r
-	return res;
+        // do N(<) A(>) VR(>)
+        int res = sat::compareByN( lhs, rhs );									// ascending  l<r
+        if ( res == 0 ) res = rhs.arch().compare( lhs.arch() );							// descending r<l
+        if ( res == 0 ) res = rhs.edition().compare( lhs.edition() );						// descending r<l
+        if ( res == 0 ) res = lhs.repository().asUserString().compare( rhs.repository().asUserString() );	// ascending  l<r
+        return res;
       }
     };
     /** Ordered MatchDetails */
@@ -69,18 +67,18 @@ namespace out
     {
       std::string xmlListElement( const sat::Solvable & match_r ) const
       {
-	str::Str str;
-	{
-	  xmlout::Node lock( str.stream(), "match", {
-	    { "kind",		match_r.kind()	},
-	    { "name",		match_r.name()	},
-	    { "edition",	match_r.edition()	},
-	    { "arch",		match_r.arch()	},
-	    { "installed",	match_r.isSystem()	},
-	    { "repo",		match_r.repository().alias()	},
-	  } );
-	}
-	return str;
+        str::Str str;
+        {
+          xmlout::Node lock( str.stream(), "match", {
+            { "kind",		match_r.kind()	},
+            { "name",		match_r.name()	},
+            { "edition",	match_r.edition()	},
+            { "arch",		match_r.arch()	},
+            { "installed",	match_r.isSystem()	},
+            { "repo",		match_r.repository().alias()	},
+          } );
+        }
+        return str;
       }
     };
 
@@ -90,41 +88,41 @@ namespace out
       str::Str str;
       // <lock>
       {
-	++_i;
-	xmlout::Node lock( str.stream(), "lock", { { "number", _i } } );
+        ++_i;
+        xmlout::Node lock( str.stream(), "lock", { { "number", _i } } );
 
-	// <name> (solvable_name)
-	for ( const std::string & val : q_r.attribute( sat::SolvAttr::name ) )
-	{ *xmlout::Node( *lock, "name" ) << val; }
-	// <name> (query_string)
-	for ( const std::string & val : q_r.strings() )
-	{ *xmlout::Node( *lock, "name" ) << val; }
+        // <name> (solvable_name)
+        for ( const std::string & val : q_r.attribute( sat::SolvAttr::name ) )
+        { *xmlout::Node( *lock, "name" ) << val; }
+        // <name> (query_string)
+        for ( const std::string & val : q_r.strings() )
+        { *xmlout::Node( *lock, "name" ) << val; }
 
-	// <type>
-	for ( const ResKind & kind : q_r.kinds() )
-	{ *xmlout::Node( *lock, "type" ) << kind; }
+        // <type>
+        for ( const ResKind & kind : q_r.kinds() )
+        { *xmlout::Node( *lock, "type" ) << kind; }
 
-	// <repo>
-	for ( const std::string & repo : q_r.repos() )
-	{ *xmlout::Node( *lock, "repo" ) << repo; }
+        // <repo>
+        for ( const std::string & repo : q_r.repos() )
+        { *xmlout::Node( *lock, "repo" ) << repo; }
 
-	// <range>
-	if ( q_r.editionRel() != Rel::ANY )
-	{
-	  dumpAsXmlOn( *lock, q_r.editionRel(), q_r.edition() );
-	}
+        // <range>
+        if ( q_r.editionRel() != Rel::ANY )
+        {
+          dumpAsXmlOn( *lock, q_r.editionRel(), q_r.edition() );
+        }
 
-	if ( _withMatches )
-	{
-	  // <matches>
-	  xmlout::Node matches( *lock, "matches", xmlout::Node::optionalContent, { { "size", q_r.size() } } );
-	  if ( _withSolvables && !q_r.empty() )
-	  {
-	    MatchDetails d;
-	    getLockDetails( q_r, d );
-	    xmlWriteContainer( *matches, d, MatchDetailFormater() );
-	  }
-	}
+        if ( _withMatches )
+        {
+          // <matches>
+          xmlout::Node matches( *lock, "matches", xmlout::Node::optionalContent, { { "size", q_r.size() } } );
+          if ( _withSolvables && !q_r.empty() )
+          {
+            MatchDetails d;
+            getLockDetails( q_r, d );
+            xmlWriteContainer( *matches, d, MatchDetailFormater() );
+          }
+        }
       }
       return str;
     }
@@ -134,8 +132,8 @@ namespace out
       TableHeader th;
       th << "#" << N_("Name");
       if ( _withMatches )
-	th << N_("Matches");
-      th << N_("Type") << N_("Repository");
+        th << N_("Matches");
+      th << N_("Type") << N_("Repository") << N_("Comment");
       return th;
     }
 
@@ -152,22 +150,22 @@ namespace out
       const PoolQuery::StrContainer & globalStrings( q_r.strings() );
 
       if ( nameStings.size() + globalStrings.size() > 1 )
-	// translators: locks table value
-	tr << _("(multiple)");
+        // translators: locks table value
+        tr << _("(multiple)");
       else if ( nameStings.empty() && globalStrings.empty() )
-	// translators: locks table value
-	tr << _("(any)");
+        // translators: locks table value
+        tr << _("(any)");
       else
-	tr << makeNameString( nameStings.empty() ? *globalStrings.begin() : *nameStings.begin(), q_r.editionRel(), q_r.edition() );
+        tr << makeNameString( nameStings.empty() ? *globalStrings.begin() : *nameStings.begin(), q_r.editionRel(), q_r.edition() );
 
       // opt Matches
       if ( _withMatches )
-	tr << q_r.size();
+        tr << q_r.size();
 
       // Type
       std::set<std::string> strings;
       for ( const ResKind & kind : q_r.kinds() )
-	strings.insert( kind.asString() );
+        strings.insert( kind.asString() );
       tr << get_string_for_table( strings );
 
       // Repository
@@ -175,35 +173,38 @@ namespace out
       copy( q_r.repos().begin(), q_r.repos().end(), inserter(strings, strings.end()) );
       tr << get_string_for_table( strings );
 
+      // Comment
+      tr << q_r.comment();
+
       // opt Solvables as detail
       if ( _withSolvables && !q_r.empty() )
       {
-	MatchDetails i;
-	MatchDetails a;
-	getLockDetails( q_r, i, a );
+        MatchDetails i;
+        MatchDetails a;
+        getLockDetails( q_r, i, a );
 
-	PropertyTable p;
-	{
-	  std::vector<std::string> names;
-	  names.reserve( std::max( i.size(), a.size() ) );
-	  if ( ! i.empty() )
-	  {
-	    //names.clear();
-	    for ( const auto & solv : i )
-	    { names.push_back( solv.asUserString() ); }
-	    // translators: property name; short; used like "Name: value"
-	    p.add( _("Keep installed"), names );
-	  }
-	  if ( ! a.empty() )
-	  {
-	    names.clear();
-	    for ( const auto & solv : a )
-	    { names.push_back( solv.asUserString() ); }
-	    // translators: property name; short; used like "Name: value"
-	    p.add( _("Do not install"), names );
-	  }
-	}
-	tr.addDetail( str::Str() << p );
+        PropertyTable p;
+        {
+          std::vector<std::string> names;
+          names.reserve( std::max( i.size(), a.size() ) );
+          if ( ! i.empty() )
+          {
+            //names.clear();
+            for ( const auto & solv : i )
+            { names.push_back( solv.asUserString() ); }
+            // translators: property name; short; used like "Name: value"
+            p.add( _("Keep installed"), names );
+          }
+          if ( ! a.empty() )
+          {
+            names.clear();
+            for ( const auto & solv : a )
+            { names.push_back( solv.asUserString() ); }
+            // translators: property name; short; used like "Name: value"
+            p.add( _("Do not install"), names );
+          }
+        }
+        tr.addDetail( str::Str() << p );
       }
       return tr;
     }
@@ -219,7 +220,7 @@ namespace out
       str::Str ret;
       ret << name_r;
       if ( op_r != Rel::ANY )
-	ret << " " << op_r << " " << edition_r;
+        ret << " " << op_r << " " << edition_r;
       return ret;
     }
 
@@ -227,11 +228,11 @@ namespace out
     {
       std::string ret;
       if ( attrvals_r.empty() )
-	ret = _("(any)");
+        ret = _("(any)");
       else if ( attrvals_r.size() > 1 )
-	ret = _("(multiple)");
+        ret = _("(multiple)");
       else
-	ret = *attrvals_r.begin();
+        ret = *attrvals_r.begin();
       return ret;
     }
 
@@ -305,7 +306,7 @@ int ListLocksCmd::execute(Zypper &zypper, const std::vector<std::string> &positi
   Out & out( zypper.out() );
   out.gap();
   out.table( "locks", locks.empty() ? _("There are no package locks defined.") : "",
-	     locks, out::LocksTableFormater( _solvables, _matches ) );
+             locks, out::LocksTableFormater( _solvables, _matches ) );
   out.gap();
 
   return 0;
